=======
Credits
=======

**django-nose** was created by Jeff Balogh in 2009, which is a really long time
ago in the Django world.  It keeps running because of the contributions of
volunteers.  Thank you to everyone who uses django-nose, keeps your projects
up-to-date, files detailed bugs, and submits patches.

Maintainers
-----------
* Jeff Balogh (`jbalogh <https://github.com/jbalogh>`_)
* Erik Rose (`erikrose <https://github.com/erikrose>`_)
* James Socol (`jscol <https://github.com/jsocol>`_)
* Rob Hudson (`robhudson <https://github.com/robhudson>`_)
* John Whitlock (`jwhitlock <https://github.com/jwhitlock>`_)

Contributors
------------
These non-maintainers have contributed code to a django-nose release:

* Adam DePue (`adepue <https://github.com/adepue>`_)
* Alexey Evseev (`st4lk <https://github.com/st4lk>`_)
* Alex (`alexjg <https://github.com/alexjg>`_)
* Antti Kaihola (`akaihola <https://github.com/akaihola>`_)
* Ash Christopher (`ashchristopher <https://github.com/ashchristopher>`_)
* Blake Winton (`bwinton <https://github.com/bwinton>`_)
* Brad Pitcher (`brad <https://github.com/brad>`_)
* Camilo Nova (`camilonova <https://github.com/camilonova>`_)
* Carl Meyer (`carljm <https://github.com/carljm>`_)
* Conrado Buhrer (`conrado <https://github.com/conrado>`_)
* David Baumgold (`singingwolfboy <https://github.com/singingwolfboy>`_)
* David Cramer (`dcramer <https://github.com/dcramer>`_)
* Dmitry Gladkov (`dgladkov <https://github.com/dgladkov>`_)
* Ederson Mota (`edrmp <https://github.com/edrmp>`_)
* Eric Zarowny (`ezarowny <https://github.com/ezarowny>`_)
* Eron Villarreal (`eroninjapan <https://github.com/eroninjapan>`_)
* Fred Wenzel (`fwenzel <https://github.com/fwenzel>`_)
* Fábio Santos (`fabiosantoscode <https://github.com/fabiosantoscode>`_)
* Ionel Cristian Mărieș (`ionelmc <https://github.com/ionelmc>`_)
* Jeremy Satterfield (`jsatt <https://github.com/jsatt>`_)
* Johan Euphrosine (`proppy <https://github.com/proppy>`_)
* Kyle Robertson (`dvelyk <https://github.com/dvelyk>`_)
* Marius Gedminas (`mgedmin <https://github.com/mgedmin>`_)
* Martin Chase (`outofculture <https://github.com/outofculture>`_)
* Matthias Bauer (`moeffju <https://github.com/moeffju>`_)
* Michael Elsdörfer (`miracle2k <https://github.com/miracle2k>`_)
* Michael Kelly (`Osmose <https://github.com/Osmose>`_)
* Peter Baumgartner (`ipmb <https://github.com/ipmb>`_)
* Radek Simko (`radeksimko <https://github.com/radeksimko>`_)
* Ramiro Morales (`ramiro <https://github.com/ramiro>`_)
* Rob Madole (`robmadole <https://github.com/robmadole>`_)
* Roger Hu (`rogerhu <https://github.com/rogerhu>`_)
* Ross Lawley (`rozza <https://github.com/rozza>`_)
* Scott Sexton (`scottsexton <https://github.com/scottsexton>`_)
* Stephen Burrows (`melinath <https://github.com/melinath>`_)
* Sverre Johansen (`sverrejoh <https://github.com/sverrejoh>`_)
* Tim Child (`timc3 <https://github.com/timc3>`_)
* Walter Doekes (`wdoekes <https://github.com/wdoekes>`_)
* Will Kahn-Greene (`willkg <https://github.com/willkg>`_)
* Yegor Roganov (`roganov <https://github.com/roganov>`_)
